import {select,json,csv,geoPath,geoAlbersUsa,scaleThreshold,scaleOrdinal,schemeGreens,filter} from 'd3';
import {feature} from 'topojson';

import React, {useCallback, useState, useMemo} from 'react';
import ReactDOM from 'react-dom';
import {VoronoiOverlay} from './VoronoiOverlay';
import {scaleTime, extent, scaleLog, max, line, timeFormat, format} from 'd3';
import {colorLegend} from './colorLegend';

const svg = select('svg');
const projection = geoAlbersUsa();
const pathGenerator = geoPath().projection(projection);
const colorLegendG = svg.append('g')
    .attr('transform', `translate(840,310)`);

const g = svg.append('g');

Promise.all([
	csv('https://raw.githubusercontent.com/andycho97/COVID_Visualization_Project/main/D3Map.csv'),
  json('https://vizhub.com/elaine-xiao/datasets/states-10m.json')
]).then(([csvData, topoJASONdata]) => {
  
  const regionname = {};
  const positive_test = {};
  const positivenumlog = {};
  const testNum = {};
  const positivity = {};
  const positive_test_percapita = {};
  const colorsample = {};
  
  csvData.forEach(d => {
    
    regionname[d.state_name] = d.seven_day_average_death_toll;
    positive_test[d.state_name] = d.seven_day_average_Positive;
    positivenumlog[d.state_name] = Math.log((+d.seven_day_average_Positive)+1);
    testNum[d.state_name] = d.seven_day_average_Tests;
    positivity[d.state_name] = d.seven_day_positivity_rate;
  	positive_test_percapita[d.state_name] = d.seven_day_average_Positive_percapita;
  
  });

  
  const states = feature(topoJASONdata, topoJASONdata.objects.states);
  const colorScale = scaleThreshold().domain([1,4,8,12,16,20,24,28]);
  const colorValue = d => positivity[d.properties.name];
  
  colorScale.domain(colorScale.domain().filter(function (el) {
  return el != null;}).sort())
  .range(schemeGreens[8]);
  
  colorLegendG.call(colorLegend, {
    colorScale,
    circleRadius: 8,
    spacing: 20,
    textOffset: 12,
    backgroundRectWidth: 235
  });
  
	g.selectAll('path')
  	.data(states.features)
    .enter()
    	.append('path')
  			.attr('class', 'state')
  			.attr('d', pathGenerator)
  			.attr('fill', d => colorScale(colorValue(d)))
  		.append('title')
  			.text("State: ")
  		.append('title1')
  			.text(d => d.properties.name)
    	.append('title2')
  			.text("\n7-Day Avg Death: ")
  		.append('title3')
  			.text(d => regionname[d.properties.name])
     	.append('title4')
  			.text("\n7-Day Avg Positive Test: ")
  		.append('title5')
  			.text(d => positive_test[d.properties.name])
  		.append('title4-1')
  			.text("\n7-Day Avg Positive Test per 100,000: ")
  		.append('title5-1')
  			.text(d => positive_test_percapita[d.properties.name])
  		.append('title6')
  			.text("\n7-Day Avg Tests: ")
  		.append('title7')
  			.text(d => testNum[d.properties.name])
  		.append('title8')
  			.text("\n7-Day Avg Positivity Rate (%): ")
  		.append('title9')
  			.text(d => positivity[d.properties.name]); 
 
});